﻿<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="html" encoding="UTF-8" indent="yes" omit-xml-declaration="yes"/>

	<!-- external references -->
	<xsl:variable name="field_name_list"	    		select="document('field_list.xml')//field_list/field"/>
	<xsl:variable name="virus_scan_detect_list"	        select="document('virus_scan_detect_table.xml')//virus_scan_detect_description/type"/>
	<xsl:variable name="virus_risk_level_list"	        select="document('virus_risk_level_table.xml')//virus_risk_level_description/type"/>
	<xsl:variable name="virus_type_list"	        	select="document('virus_type_table.xml')//virus_type_description/type"/>
	<xsl:variable name="atse_rule_category_list"	    select="document('atse_rule_category_table.xml')//atse_rule_category_description/type"/>
	<xsl:variable name="action_description_list"		select="document('action_descriptions.xml')//action_description/action"/>
	<xsl:variable name="virus_encyclopedia_link"		select="document('localization.xml')/strings/group[@name='log']/string[@name='virus_encyclopedia_link']"/>
	<xsl:variable name="virus_name_over_restriction"	select="document('localization.xml')/strings/group[@name='log']/string[@name='virus_name_over_restriction']"/>
	<xsl:variable name="virus_name_password_protected"	select="document('localization.xml')/strings/group[@name='log']/string[@name='virus_name_password_protected']"/>
	<xsl:variable name="virus_name_suspicious_content"	select="document('localization.xml')/strings/group[@name='log']/string[@name='virus_name_suspicious_content']"/>	
	<xsl:variable name="virus_name_unrated_content"	    select="document('localization.xml')/strings/group[@name='log']/string[@name='virus_name_unrated_content']"/>
	<xsl:variable name="log_print"      select="document('pr_status.xml')/pr/log_print"/>
	<xsl:variable name="event_type_list"   select="document('event_tracking.xml')//event_tracking/event_type"/>
	<xsl:variable name="source_type_list"  select="document('event_tracking.xml')//event_tracking/source_type"/>
	<xsl:variable name="dda_int_mode_list"				select="document('dda_int_mode_table.xml')//dda_int_mode_description/type"/>
	<xsl:variable name="dda_ui_status_list"				select="document('dda_ui_status_table.xml')//dda_ui_status_description/type"/>
	
	<!-- internal settings -->
	<xsl:variable name="virus_name_over_restriction_internal"	>over restriction</xsl:variable>
	<xsl:variable name="virus_name_password_protected_internal"	>protected file</xsl:variable>


	<!-- ||TEMPLATE: Main iteration -->
	<xsl:template match="/">
	<table width="100%" border="0" cellpadding="0" cellspacing="0">
	<!-- header fields -->
		<tr>
			<xsl:for-each select="//record[1]/@*">
				<xsl:variable name="current_field_tag" select="name(.)"></xsl:variable>
				<xsl:variable name="current_field_name"	select="$field_name_list[@name=$current_field_tag]"></xsl:variable>
        <td>
          <xsl:choose>
            <xsl:when test="$current_field_tag = 'msg_subject'">
              <xsl:attribute name="width">
                100px
              </xsl:attribute>
            </xsl:when>
            <xsl:when test="$current_field_tag = 'filter_action'">
              <xsl:attribute name="width">
                100px
              </xsl:attribute>
            </xsl:when>
          </xsl:choose>
          
          <xsl:attribute name="nowrap">
            nowrap
          </xsl:attribute>
          <xsl:attribute name="class">
            grey2<xsl:if test="position()=last()">-end</xsl:if>
          </xsl:attribute>
          <xsl:attribute name="id">
            <xsl:value-of select="$current_field_tag"/>
          </xsl:attribute>

          <xsl:if test="$log_print != '1'">
            <xsl:choose>
              <xsl:when test="$current_field_tag='storage_entry_id'">
                  <input type="checkbox" name="chkSelectAll" onclick="jsSelectAll();"/>
              </xsl:when>
              <xsl:otherwise>
				<xsl:if test="$current_field_tag != 'activity_description' and $current_field_tag != 'remote_server_name' and $current_field_tag != 'DataContent'">
                  <a>
                    <xsl:attribute name="href">
                      javascript: jsToggleSort("<xsl:value-of select="$current_field_tag"/>")
                    </xsl:attribute>
                    <xsl:choose>
                      <xsl:when test="$current_field_name">
                        <xsl:value-of select="$current_field_name"/>
                      </xsl:when>
                      <xsl:otherwise>
                        <font color="red">
                          <xsl:value-of select="$current_field_tag"/>
                        </font>
                      </xsl:otherwise>
                    </xsl:choose>
                  </a>
				</xsl:if>
				<xsl:if test="$current_field_tag = 'activity_description' or $current_field_tag = 'remote_server_name' or $current_field_tag = 'DataContent'">
                  <xsl:choose>
                    <xsl:when test="$current_field_name">
                      <xsl:value-of select="$current_field_name"/>
                    </xsl:when>
                    <xsl:otherwise>
                      <font color="red">
                        <xsl:value-of select="$current_field_tag"/>
                      </font>
                    </xsl:otherwise>
                  </xsl:choose>
                </xsl:if>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:if>

          <xsl:if test="$log_print = '1'">
            <xsl:choose>
              <xsl:when test="$current_field_name">
                <xsl:value-of select="$current_field_name"/>
              </xsl:when>
              <xsl:otherwise>
                <font color="red">
                  <xsl:value-of select="$current_field_tag"/>
                </font>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:if>

        </td>
			</xsl:for-each>	
		</tr>
	<!--/ header fields -->
	<!-- content fields -->
		<xsl:for-each select="//record">
			<xsl:variable name="toggle"	select="boolean(position() mod 2)"/>
			<xsl:variable name="filter_action" select="@filter_action"/>
			<tr>
			<xsl:for-each select="@*">
        <xsl:variable name="current_field_tag" select="name(.)"></xsl:variable>
        <td>
          <xsl:variable name="islast" select="boolean(position() = last())"/>
          <xsl:variable name="current_value" select="."></xsl:variable>
          <xsl:variable name="col_style">
            <xsl:choose>
              <xsl:when test="$toggle">data1</xsl:when>
              <xsl:otherwise>data2</xsl:otherwise>
            </xsl:choose>
            <xsl:if test="position()!=last()">b</xsl:if>
          </xsl:variable>
          <xsl:attribute name="class">
            <xsl:value-of select="$col_style"/>
          </xsl:attribute>
         
          <xsl:choose>
            <xsl:when test="$current_field_tag != 'storage_entry_id'">
              <xsl:apply-templates select="."/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:choose>
                <xsl:when test=" . = '' ">
                  <center>　</center>
                </xsl:when>
                <xsl:otherwise>
              		<!-- I don't know how to write the following statement in xslt:
									if( filter_action=73 || filter_action=23 )
									So I wrote a lot of statements to simulate that... -->
									<xsl:choose>
										<xsl:when test="$filter_action=73">
											<center>
		                    <input type="checkbox" name="chkResendId" onclick="jsItems_Click(document.fmQMCmd.chkSelectAll, document.fmQMCmd.chkResendId, true);">
		                      <xsl:attribute name="value">
		                        <xsl:value-of select="concat(.,'|',$filter_action)"/>
		                      </xsl:attribute>
		                    </input>
		                  </center>
										</xsl:when>
                    <xsl:when test="$filter_action=23">
                      <center>
                        <input type="checkbox" name="chkResendId" onclick="jsItems_Click(document.fmQMCmd.chkSelectAll, document.fmQMCmd.chkResendId, true);">
                          <xsl:attribute name="value">
                            <xsl:value-of select="concat(.,'|',$filter_action)"/>
                          </xsl:attribute>
                        </input>
                      </center>
                    </xsl:when>
                    <xsl:when test="$filter_action=59">
                      <center>
                        <input type="checkbox" name="chkResendId" onclick="jsItems_Click(document.fmQMCmd.chkSelectAll, document.fmQMCmd.chkResendId, true);">
                          <xsl:attribute name="value">
                            <xsl:value-of select="concat(.,'|',$filter_action)"/>
                          </xsl:attribute>
                        </input>
                      </center>
                    </xsl:when>
                    <xsl:when test="$filter_action=29">
                      <center>
                        <input type="checkbox" name="chkResendId" onclick="jsItems_Click(document.fmQMCmd.chkSelectAll, document.fmQMCmd.chkResendId, true);">
                          <xsl:attribute name="value">
                            <xsl:value-of select="concat(.,'|',$filter_action)"/>
                          </xsl:attribute>
                        </input>
                      </center>
                    </xsl:when>
                    <xsl:when test="$filter_action=79">
                      <center>
                        <input type="checkbox" name="chkResendId" onclick="jsItems_Click(document.fmQMCmd.chkSelectAll, document.fmQMCmd.chkResendId, true);">
                          <xsl:attribute name="value">
                            <xsl:value-of select="concat(.,'|',$filter_action)"/>
                          </xsl:attribute>
                        </input>
                      </center>
                    </xsl:when>
                    <xsl:when test="$filter_action=86">
                      <center>
                        <input type="checkbox" name="chkResendId" onclick="jsItems_Click(document.fmQMCmd.chkSelectAll, document.fmQMCmd.chkResendId, true);">
                          <xsl:attribute name="value">
                            <xsl:value-of select="concat(.,'|',$filter_action)"/>
                          </xsl:attribute>
                        </input>
                      </center>
                    </xsl:when>
                    <xsl:otherwise>
										    <center>　</center>
										</xsl:otherwise>
									</xsl:choose>
                </xsl:otherwise>
              </xsl:choose>


            </xsl:otherwise>
          </xsl:choose>
        </td>
			</xsl:for-each>
			</tr>
		</xsl:for-each>
	<!--/ content fields-->
	</table>
	</xsl:template>	


	<!-- ||TEMPLATE: ordinary fields -->
	<xsl:template match="record/@*">
		<xsl:call-template name="escape_special">
			<xsl:with-param name="value" select="."/>
		</xsl:call-template>
		<xsl:if test="normalize-space(.)=''"><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></xsl:if>
	</xsl:template>
	

	<!-- ||TEMPLATE: action field -->
	<xsl:template match="record/@*[name(.)='filter_action']">
		<xsl:value-of select="$action_description_list[@id=current()/.]"/>
	</xsl:template>

        <!-- ||TEMPLATE: virus type field -->
	<xsl:template match="record/@*[name(.)='filter_rule_supplement']">
		<xsl:value-of select="$virus_type_list[@id=current()/.]"/>
	</xsl:template>
	
        <!-- ||TEMPLATE: virus scan detecte type field -->
	<xsl:template match="record/@*[name(.)='detected_by']">
		<xsl:value-of select="$virus_scan_detect_list[@id=current()/.]"/>
	</xsl:template>
	
		<!-- ||TEMPLATE: virus scan detected rule category type field -->
	<xsl:template match="record/@*[name(.)='detected_rule_category']">
		<xsl:value-of select="$atse_rule_category_list[@id=current()/.]"/>
	</xsl:template>
	
        <!-- ||TEMPLATE: virus risk level from DTAS field -->
	<xsl:template match="record/@*[name(.)='risk_level']">
		<xsl:value-of select="$virus_risk_level_list[@id=current()/.]"/>
	</xsl:template>	

	    <!-- ||TEMPLATE: dda int mode from DDAn field -->
	<xsl:template match="record/@*[name(.)='dda_int_mode']">
		<xsl:value-of select="$dda_int_mode_list[@id=current()/.]"/>
	</xsl:template>	
	
	    <!-- ||TEMPLATE: dda int mode from DDAn field -->
	<xsl:template match="record/@*[name(.)='dda_ui_status']">
		<xsl:value-of select="$dda_ui_status_list[@id=current()/.]"/>
	</xsl:template>		
		
	<xsl:template name="escape_special">
		<xsl:param name="value"/>
		<xsl:choose>
			<xsl:when test="contains($value, ' ')"><xsl:call-template name="escape_quot"><xsl:with-param name="substr" select="$value"/></xsl:call-template></xsl:when>
			<xsl:otherwise><xsl:value-of select="$value"/></xsl:otherwise>
		</xsl:choose>	
	</xsl:template>
	
	<xsl:template name="escape_quot">
		<xsl:param name="substr"/>
		<xsl:choose>
			<xsl:when test="contains($substr, ' ')">
				<xsl:variable name="str_before_quot" select="substring-before($substr, ' ')"/>
				<xsl:variable name="str_after_quot" select="substring-after($substr, ' ')"/>
				<xsl:value-of select="$str_before_quot"/><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text><xsl:text/>	
				<xsl:call-template name="escape_quot">
					<xsl:with-param name="substr" select="$str_after_quot"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$substr"/>
			</xsl:otherwise>	
		</xsl:choose>
	</xsl:template>

	<!-- ||TEMPLATE: virus description -->
	<xsl:template match="record/@*[name(.)='filter_rule_av']">
		<xsl:choose>
			<xsl:when test="starts-with(., $virus_name_over_restriction)"><xsl:value-of select="."/></xsl:when>
			<xsl:when test="starts-with(., $virus_name_suspicious_content)"><xsl:value-of select="."/></xsl:when>
			<xsl:when test="starts-with(., $virus_name_unrated_content)"><xsl:value-of select="."/></xsl:when>
			<xsl:when test=".=$virus_name_password_protected"><xsl:value-of select="."/></xsl:when>
			<xsl:otherwise>
			    <a target="_new">
					<xsl:attribute name="href">
						<xsl:value-of select="$virus_encyclopedia_link"/>
						<xsl:value-of select="."/>
					</xsl:attribute>
					<xsl:value-of select="."/>
				</a>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

  <!-- ||TEMPLATE: Event Tracking : Event Type field -->
  <xsl:template match="record/@*[name(.)='EventType']">
	<xsl:attribute name="nowrap">
        nowrap
    </xsl:attribute>
    <xsl:value-of select="$event_type_list[@id=current()/.]"/>
  </xsl:template>
  
  <!-- ||TEMPLATE: Event Tracking : User Name field -->
  <xsl:template match="record/@*[name(.)='UserName']">
	<xsl:attribute name="nowrap">
        nowrap
    </xsl:attribute>
	<xsl:value-of select="."/>
  </xsl:template>

  <!-- ||TEMPLATE: Event Tracking : Source Type field -->
  <xsl:template match="record/@*[name(.)='SourceType']">
    <xsl:value-of select="$source_type_list[@id=current()/.]"/>
  </xsl:template>
  
</xsl:stylesheet>
