<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
      xmlns:msxsl="urn:schemas-microsoft-com:xslt"
      xmlns:trend="http://trendmicro.com/smex">
	<xsl:output method="html" version="1.0" encoding="UTF-8" indent="yes"/>

	<xsl:decimal-format name="us" 		decimal-separator='.' grouping-separator=',' />
	<xsl:decimal-format name="european" decimal-separator=',' grouping-separator='.' />

	<xsl:variable name="dec-format"		select="document('localization.xml')/strings/group[@name='report']/decimal-format"/>
	<xsl:variable name="date-format"	select="document('localization.xml')/strings/group[@name='report']/date-format"/>
	<xsl:variable name="time-format"	select="document('localization.xml')/strings/group[@name='report']/time-format"/>
	<xsl:variable name="hour-format"	select="document('localization.xml')/strings/group[@name='report']/hour-format"/>

<!--|| TEMPLATE : generic number formation -->
	<xsl:template name="format_number">
		<xsl:param name="num"/>
		<xsl:variable name="num_">
			<xsl:choose>
				<xsl:when test="not(boolean(number($num)))">0</xsl:when>
				<xsl:otherwise><xsl:value-of select="$num"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:value-of select="format-number($num_, '###,##0.####', $dec-format)"/>
	</xsl:template>


<!--|| TEMPLATE : integer number formation -->
	<xsl:template name="format_int_number">
		<xsl:param name="num"/>
		<xsl:variable name="num_">
			<xsl:choose>
				<xsl:when test="not(boolean(number($num)))">0</xsl:when>
				<xsl:otherwise><xsl:value-of select="$num"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:value-of select="format-number($num_, '###,##0', $dec-format)"/>
	</xsl:template>


<!--|| TEMPLATE : float number formation -->
	<xsl:template name="format_float_number">
		<xsl:param name="num"/>
		<xsl:variable name="num_">
			<xsl:choose>
				<xsl:when test="not(boolean(number($num)))">0</xsl:when>
				<xsl:otherwise><xsl:value-of select="$num"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:value-of select="format-number($num_, '###,##0.####', $dec-format)"/>
	</xsl:template>


<!--|| TEMPLATE : make percentage -->
	<xsl:template name="format_percentage">
		<xsl:param name="numerator"/>
		<xsl:param name="denominator"/>
		<xsl:variable name="output-number">
			<xsl:choose>
				<xsl:when test="not(boolean(number($numerator))) or ($numerator = 0)">0</xsl:when>
				<xsl:when test="not(boolean(number($denominator)))">0</xsl:when>
				<xsl:otherwise><xsl:value-of select="number($numerator) div number($denominator)"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:value-of select="format-number($output-number, '###,##0.##%', $dec-format)"/>
	</xsl:template>


<!--|| DATETIME SCRIPT FUNCTION -->
	<msxsl:script language="JScript" implements-prefix="trend"><![CDATA[
		function GetLocaleDateTimeString(datetime_string, part)
		{
			var oDate = new Date(datetime_string);
			if (part == 'to_datetime')
				return oDate.toLocaleString();
			else if (part == 'to_date')
			{
				var sLocaleDateString = "";
				try
				{
					sLocaleDateString = oDate.toLocaleDateString();
				}
				catch (e)
				{
				}
				return sLocaleDateString;
			}
			else if (part == 'to_time')
			{
				var sLocaleTimeString = "";
				try
				{
					sLocaleTimeString = oDate.toLocaleTimeString();
				}
				catch (e)
				{
				}
				return sLocaleTimeString;
			}
			else
				return "";
		}
		
		//function dbgLog(s)
		//{
		//	var fso = new ActiveXObject("Scripting.FileSystemObject");
		//	var f = fso.OpenTextFile("c:\\jslog.txt", 8, true);
		//	f.WriteLine(s);
		//	f.Close();
		//	fso = null;
		//}
		
		function pad (val, len) {
			val = String(val);
			len = len || 2;
			while (val.length < len) val = "0" + val;
			return val;
		}
			
		function formatDateTime (dt, msk) {
			var mask = msk;
			
			var utc = false;
			if (mask == "")
				return dt;
			
			var	token = /d{1,4}|m{1,4}|yy(?:yy)?|([HhMsTt])\1?|[LloSZ]|"[^"]*"|'[^']*'/g,
			timezone = /\b(?:[PMCEA][SDP]T|(?:Pacific|Mountain|Central|Eastern|Atlantic) (?:Standard|Daylight|Prevailing) Time|(?:GMT|UTC)(?:[-+]\d{4})?)\b/g,
			timezoneClip = /[^-+\dA-Z]/g;
			
			// Passing date through Date applies Date.parse, if necessary
			var date = new Date(dt);
			if (isNaN(date)) {
				return dt;
			}
		
			// Allow setting the utc argument via the mask
			if (mask.slice(0, 4) == "UTC:") {
				mask = mask.slice(4);
				utc = true;
			}
			
			var i18n = {
				dayNames: [
					"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat",
					"Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"
				],
				monthNames: [
					"Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec",
					"January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"
				]
			};
		
			var	_ = "get",
				d = date[_ + "Date"](),
				D = date[_ + "Day"](),
				m = date[_ + "Month"](),
				y = date[_ + "FullYear"](),
				H = date[_ + "Hours"](),
				M = date[_ + "Minutes"](),
				s = date[_ + "Seconds"](),
				L = date[_ + "Milliseconds"](),
				o = utc ? 0 : date.getTimezoneOffset(),
				flags = {
					d:    d,
					dd:   pad(d),
					ddd:  i18n.dayNames[D],
					dddd: i18n.dayNames[D + 7],
					M:    m + 1,
					MM:   pad(m + 1),
					MMM:  i18n.monthNames[m],
					MMMM: i18n.monthNames[m + 12],
					yy:   String(y).slice(2),
					yyyy: y,
					h:    H % 12 || 12,
					hh:   pad(H % 12 || 12),
					H:    H,
					HH:   pad(H),
					m:    M,
					mm:   pad(M),
					s:    s,
					ss:   pad(s),
					l:    pad(L, 3),
					L:    pad(L > 99 ? Math.round(L / 10) : L),
					t:    H < 12 ? "a"  : "p",
					tt:   H < 12 ? "am" : "pm",
					T:    H < 12 ? "A"  : "P",
					TT:   H < 12 ? "AM" : "PM",
					Z:    utc ? "UTC" : (String(date).match(timezone) || [""]).pop().replace(timezoneClip, ""),
					o:    (o > 0 ? "-" : "+") + pad(Math.floor(Math.abs(o) / 60) * 100 + Math.abs(o) % 60, 4),
					S:    ["th", "st", "nd", "rd"][d % 10 > 3 ? 0 : (d % 100 - d % 10 != 10) * d % 10]
				};
		
			return mask.replace(token, 
				function ($0) {
					return $0 in flags ? flags[$0] : $0.slice(1, $0.length - 1);
				}
			);
		}
	
	//]]>
	</msxsl:script>

<!--|| TEMPLATE: Datetime formation -->
	<xsl:template name="format_datetime_string" xmlns:ms="urn:schemas-microsoft-com:xslt">
		<xsl:param name="datetime_string"/>
		<xsl:variable name="datetime_string_normalize" select="translate($datetime_string, '-', '/')"/>
		<xsl:value-of select="trend:GetLocaleDateTimeString($datetime_string_normalize, 'to_datetime')"/>
	</xsl:template>

	<xsl:template name="format_datehour_string" xmlns:ms="urn:schemas-microsoft-com:xslt">
		<xsl:param name="datetime_string"/>
		<xsl:variable name="xsd_datetime_string" select="translate($datetime_string, '-', '/')"/>
		<xsl:variable name="xsd_hour_format" select="document('localization.xml')/strings/group[@name='report']/hour-format"/>
		<xsl:call-template name="format_date_string">
			<xsl:with-param name="datetime_string" select="$datetime_string"/>
		</xsl:call-template>
		<xsl:text> </xsl:text>
		<xsl:value-of select="trend:formatDateTime($xsd_datetime_string, string($xsd_hour_format))"/>:00
	</xsl:template>

	<xsl:template name="format_date_string" xmlns:ms="urn:schemas-microsoft-com:xslt">
		<xsl:param name="datetime_string"/>
		<xsl:variable name="datetime_string_normalize" select="translate($datetime_string, '-', '/')"/>
		<xsl:variable name="datetime_string_localized" select="trend:GetLocaleDateTimeString($datetime_string_normalize, 'to_date')"/>
		<xsl:variable name="xsd_date_format" select="document('localization.xml')/strings/group[@name='report']/date-format"/>
		<xsl:choose>
			<xsl:when test="$datetime_string_localized=''">
				<xsl:variable name="xsd_datetime_string" select="translate($datetime_string, '-', '/')"/>
				<xsl:value-of select="trend:formatDateTime($xsd_datetime_string, string($xsd_date_format))"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$datetime_string_localized"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="format_time_string" xmlns:ms="urn:schemas-microsoft-com:xslt">
		<xsl:param name="datetime_string"/>
		<xsl:variable name="datetime_string_normalize" select="translate($datetime_string, '-', '/')"/>
		<xsl:variable name="datetime_string_localized" select="trend:GetLocaleDateTimeString($datetime_string_normalize, 'to_time')"/>
		<xsl:variable name="xsd_time_format" select="document('localization.xml')/strings/group[@name='report']/time-format"/>
		<xsl:choose>
			<xsl:when test="$datetime_string_localized=''">
				<xsl:variable name="xsd_datetime_string" select="translate($datetime_string, '-', '/')"/>
				<xsl:value-of select="trend:formatDateTime($xsd_datetime_string, string($xsd_time_format))"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$datetime_string_localized"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>
