<?xml version="1.0" encoding="utf-8"?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:variable name="var-server-name" select="/database_configuration/server_name"/>
<xsl:variable name="var-database-type" select="/database_configuration/database_type"/>

<xsl:template match="/">
<database>
  <database_installation>
    <xsl:for-each select="/database_configuration/database_installation/*">
      <xsl:if test="not(name() = 'schema_upgrade')">
        <xsl:apply-templates select="."/>
      </xsl:if>
    </xsl:for-each>
  </database_installation>
  <database_uninstallation>
    <xsl:for-each select="/database_configuration/database_uninstallation/*">
      <xsl:if test="not(name() = 'schema_rollback')">
        <xsl:apply-templates select="."/>
      </xsl:if>
    </xsl:for-each>
  </database_uninstallation>
 </database>
</xsl:template>

<xsl:template match="/database_configuration/database_installation/sql">
  <xsl:copy-of select="."/>
</xsl:template>

<xsl:template match="/database_configuration/database_uninstallation/sql">
  <xsl:copy-of select="."/>
</xsl:template>

<xsl:template match="/database_configuration/database_installation/schema_definition">
  <xsl:variable name="var-schema-definition" select="document(@src)"/>

  <xsl:choose>
    <xsl:when test="/database_configuration/database_installation/schema_upgrade">
      <xsl:call-template name="upgrade">
        <xsl:with-param name="param-schema" select="$var-schema-definition/database/schema"/>
        <xsl:with-param name="param-schema-upgrade" select="/database_configuration/database_installation/schema_upgrade"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:call-template name="install">
        <xsl:with-param name="param-schema" select="$var-schema-definition/database/schema"/>
      </xsl:call-template>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="/database_configuration/database_uninstallation/schema_definition">
  <xsl:variable name="var-schema-definition" select="document(@src)"/>

      <xsl:call-template name="rollback">
        <xsl:with-param name="param-schema" select="$var-schema-definition/database/schema"/>
        <xsl:with-param name="param-schema-rollback" select="/database_configuration/database_uninstallation/schema_rollback"/>
      </xsl:call-template>
  
</xsl:template>

<xsl:template name="string-replace-all">
    <xsl:param name="text" />
    <xsl:param name="replace" />
    <xsl:param name="by" />
    <xsl:choose>
      <xsl:when test="contains($text, $replace)">
        <xsl:value-of select="substring-before($text,$replace)" />
        <xsl:value-of select="$by" />
        <xsl:call-template name="string-replace-all">
          <xsl:with-param name="text"
          select="substring-after($text,$replace)" />
          <xsl:with-param name="replace" select="$replace" />
          <xsl:with-param name="by" select="$by" />
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$text" />
      </xsl:otherwise>
    </xsl:choose>
</xsl:template>


<!--// Template: Generate installation Sql scripts -->
<xsl:template name="install">
	<xsl:param name="param-schema"/>
	<xsl:for-each select="$param-schema/table">
		<sql>
		<xsl:apply-templates select="."/>
		</sql>
	</xsl:for-each>
  
  <xsl:for-each select="$param-schema/table/instance">
  <sql>
    <xsl:call-template name="insert-instance">
      <xsl:with-param name="param-table" select=".."/>
      <xsl:with-param name="param-row-instance" select="."/>
    </xsl:call-template>
  </sql>
  </xsl:for-each>

  <xsl:for-each select="$param-schema/view">
	<sql>
		<xsl:apply-templates select="."/>
	</sql>
	</xsl:for-each>

  <xsl:for-each select="$param-schema/table/field[@index]">
  <sql>
    <xsl:call-template name="create-index">
      <xsl:with-param name="param-table" select=".."/>
      <xsl:with-param name="param-field" select="."/>
    </xsl:call-template>
  </sql>
  </xsl:for-each>
</xsl:template>


<!--// Template: Generate upgrade sql scripts -->
<xsl:template name="upgrade">
	<xsl:param name="param-schema"/>
	<xsl:param name="param-schema-upgrade"/>

	<!-- INSTALL NEW TABLES AND UPGRADE EXISTING TABLES -->
	<xsl:for-each select="$param-schema/table">
	<xsl:call-template name="upgrade-table">
		<xsl:with-param name="param-table" select="."/>
		<xsl:with-param name="param-table-upgrade" select="$param-schema-upgrade/table[@name=current()/@name]"/>
	</xsl:call-template>
	</xsl:for-each>

	<!-- DROP OTHER TABLES -->
	<xsl:for-each select="$param-schema-upgrade/table">
	<xsl:if test="not($param-schema/table[@name=current()/@name])">
	<sql haltonerror="false">
	<xsl:call-template name="drop-table">
	  <xsl:with-param name="param-table-name" select="./@name"/>
	</xsl:call-template>
	</sql>
	</xsl:if>
	</xsl:for-each>
	
	<!-- UPGRADE VIEWS -->
	<xsl:for-each select="$param-schema/view">
	<xsl:call-template name="upgrade-view">
		<xsl:with-param name="param-view" select="."/>
	</xsl:call-template>
	</xsl:for-each>

  <!-- INSERT INSTANCE -->
  <!--<xsl:for-each select="$param-schema/table/instance">
  <xsl:if test="@__drop_if_exists_key">
  <xsl:variable name="var-drop-key" select="@__drop_if_exists_key"/>
  <sql>DELETE FROM [<xsl:value-of select="../@name"/>]
  WHERE [<xsl:value-of select="$var-drop-key"/>] = <xsl:call-template name="sql-value">
    <xsl:with-param name="param-value" select="@*[name()=$var-drop-key]"/>
    <xsl:with-param name="param-type" select="../field[@*[$var-drop-key]]/@type"/>
  </xsl:call-template>
  </sql>
  </xsl:if>
  <sql haltonerror="false">
  <xsl:call-template name="insert-instance">
    <xsl:with-param name="param-table" select=".."/>
    <xsl:with-param name="param-row-instance" select="."/>
  </xsl:call-template>
  </sql>
  </xsl:for-each>-->
</xsl:template>

<!--//Template: Genarate rollback sql scripts-->
<xsl:template name="rollback">
  <xsl:param name="param-schema"/>
  <xsl:param name="param-schema-rollback"/>

  <!-- DELETE NEW TABLES AND ROLLBACK EXISTING TABLES -->
  <xsl:for-each select="$param-schema-rollback/table">
    <xsl:call-template name="rollback-table">
      <xsl:with-param name="param-table" select="$param-schema/table[@name=current()/@name]"/>
      <xsl:with-param name="param-table-rollback" select="."/>
    </xsl:call-template>
  </xsl:for-each>

  <!-- CREATE TABLES DROPPED WHEN UPGRADE -->
  <xsl:for-each select="$param-schema/table">
  <xsl:if test="not($param-schema-rollback/table[@name=current()/@name])">
    <sql haltonerror="false">
      <xsl:apply-templates select="."/>
    </sql>
    </xsl:if>
  </xsl:for-each>

  <!-- UPGRADE VIEWS -->
  <xsl:for-each select="$param-schema/view">
    <xsl:call-template name="upgrade-view">
      <xsl:with-param name="param-view" select="."/>
    </xsl:call-template>
  </xsl:for-each>
  
</xsl:template>


<xsl:template name="upgrade-table">
	<xsl:param name="param-table"/>
	<xsl:param name="param-table-upgrade"/>
  <xsl:variable name="var-new-table-name" select="concat($param-table/@name,'_',$var-server-name)"/>

	<xsl:choose>
  <!-- upgrade existing columns -->
    <xsl:when test="$param-table-upgrade">
		<xsl:for-each select="$param-table/field">
		    <xsl:call-template name="upgrade-column">
		    	<!-- xsl:with-param name="param-table-name"     select="$param-table/@name"/ -->
		    	<xsl:with-param name="param-table-name"     select="$param-table/@name"/>
		    	<xsl:with-param name="param-column"         select="."/>
		    	<xsl:with-param name="param-column-upgrade" select="$param-table-upgrade/field[@name=current()/@name]"/>
		    </xsl:call-template>
            <!-- update the newly added field with default value  -->
            <xsl:if test="not($param-table-upgrade/field[@name=current()/@name]) and (not(current()/@initoninstall) or current()/@initoninstall = 'true')">
                <sql haltonerror="false">
                  UPDATE [<xsl:value-of select="$var-new-table-name"/>] SET 
                    [<xsl:value-of select="@name"/>] = <xsl:call-template name="sql-value">
                      <xsl:with-param name="param-type" select="@type"/>
                      <xsl:with-param name="param-value" select="@default"/>
                    </xsl:call-template>
                </sql>
            </xsl:if>
		</xsl:for-each>
    </xsl:when>

  <!-- add new tables -->
    <xsl:otherwise>
		<sql>
		  <xsl:apply-templates select="$param-table"/>
		</sql>
      <!-- INSERT INSTANCE -->
      <xsl:for-each select="$param-table/instance">
        <sql haltonerror="false">
          <xsl:call-template name="insert-instance">
            <xsl:with-param name="param-table" select=".."/>
            <xsl:with-param name="param-row-instance" select="."/>
          </xsl:call-template>
        </sql>
      </xsl:for-each>
    </xsl:otherwise>
	</xsl:choose>
</xsl:template>

  
<xsl:template name="rollback-table">
  <xsl:param name="param-table"/>
  <xsl:param name="param-table-rollback"/>

  <xsl:choose>
    <!-- upgrade existing columns -->
    <xsl:when test="$param-table">
      <xsl:for-each select="$param-table-rollback/field">
          <xsl:call-template name="rollback-column">
            <xsl:with-param name="param-table-name"     select="$param-table/@name"/>
            <xsl:with-param name="param-column"         select="$param-table/field[@name=current()/@name]"/>
            <xsl:with-param name="param-column-rollback" select="."/>
          </xsl:call-template>
      </xsl:for-each>
    </xsl:when>

    <!-- delete new tables -->
    <xsl:otherwise>
      <sql haltonerror="false">
        <xsl:call-template name="drop-table">
          <xsl:with-param name="param-table-name" select="$param-table-rollback/@name"/>
        </xsl:call-template>
      </sql>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="drop-table">
  <xsl:param name="param-table-name"/>
  <xsl:variable name="var-new-table-name" select="concat($param-table-name,'_',$var-server-name)"/>
  DROP TABLE <xsl:value-of select="$var-new-table-name"/>
</xsl:template>


<xsl:template name="upgrade-column">
  <xsl:param name="param-table-name"/>
  <xsl:param name="param-column"/>
  <xsl:param name="param-column-upgrade"/>
  <xsl:variable name="var-new-table-name" select="concat($param-table-name,'_',$var-server-name)"/>
  <!--if the column exist, do not update it.-->
  <!--<xsl:choose>
    <xsl:when test="$param-column-upgrade">
      ALTER TABLE [<xsl:value-of select="$param-table-name"/>] 
        ALTER COLUMN <xsl:apply-templates select="$param-column"><xsl:with-param name="param-is-upgrade">true</xsl:with-param></xsl:apply-templates>
    </xsl:when>
    <xsl:otherwise>
      ALTER TABLE [<xsl:value-of select="$param-table-name"/>]
        ADD <xsl:apply-templates select="$param-column"/>
    </xsl:otherwise>
  </xsl:choose>-->
  <xsl:if test="not($param-column-upgrade)">
    <sql haltonerror="false">
      ALTER TABLE [<xsl:value-of select="$var-new-table-name"/>]
      ADD <xsl:apply-templates select="$param-column"/>
    </sql>
  </xsl:if>
</xsl:template>

<xsl:template name="rollback-column">
  <xsl:param name="param-table-name"/>
  <xsl:param name="param-column"/>
  <xsl:param name="param-column-rollback"/>
  <xsl:variable name="var-new-table-name" select="concat($param-table-name,'_',$var-server-name)"/>
  <!--if the column exist, do not update it.-->
  <!--<xsl:choose>
    <xsl:when test="$param-column">
      ALTER TABLE [<xsl:value-of select="$param-table-name"/>]
      ALTER COLUMN <xsl:apply-templates select="$param-column">
        <xsl:with-param name="param-is-upgrade">true</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:otherwise>
      ALTER TABLE [<xsl:value-of select="$param-table-name"/>]
      DROP COLUMN [<xsl:value-of select="$param-column-rollback/@name"/>]
    </xsl:otherwise>
  </xsl:choose>-->
  <xsl:if test="not($param-column)">
    <sql haltonerror="false">
      ALTER TABLE [<xsl:value-of select="$var-new-table-name"/>]
      DROP COLUMN [<xsl:value-of select="$param-column-rollback/@name"/>]
    </sql>
  </xsl:if>
</xsl:template>


<!--// Template: Upgrade view -->
<xsl:template name="upgrade-view">
	<xsl:param name="param-view"/>
  <sql haltonerror="false">
	IF OBJECT_ID('[<xsl:value-of select="concat($param-view/@name,'_',$var-server-name)"/>]','v') IS NOT NULL
		DROP VIEW [<xsl:value-of select="concat($param-view/@name,'_',$var-server-name)"/>]
	</sql>
	<sql>
	<xsl:apply-templates select="$param-view"/>
	</sql>
</xsl:template>


<!--// Template: Create Table -->
<xsl:template match="/database/schema/table">
  <!--xsl:variable name="var-table-name" select="@name"/-->
  <xsl:variable name="var-new-table-name" select="concat(@name,'_',$var-server-name)"/>
	<xsl:text>CREATE TABLE [</xsl:text>
	<xsl:value-of select="$var-new-table-name"/>] 
	(
		<xsl:for-each select="field">
		<xsl:apply-templates select="."/> 
		<xsl:if test="position() != last()">,
		</xsl:if>
		</xsl:for-each>
	)
</xsl:template>

<xsl:template name="insert-instance">
  <xsl:param name="param-table"/>
  <xsl:param name="param-row-instance"/>
  <xsl:text>INSERT INTO [</xsl:text><xsl:value-of select="concat($param-table/@name,'_',$var-server-name)"/><xsl:text>]</xsl:text>
  (
    <xsl:for-each select="$param-row-instance/@*[name() != '__drop_if_exists_key']">
    <xsl:value-of select="name(.)"/>
    <xsl:if test="position() != last()">,</xsl:if>
    </xsl:for-each>
  )
  VALUES
  (
    <xsl:for-each select="$param-row-instance/@*[name() != '__drop_if_exists_key']">
    <xsl:variable name="var-type" select="$param-table/field[@name=name(current())]/@type"/>
    <xsl:call-template name="sql-value">
      <xsl:with-param name="param-type" select="$var-type"/>
      <xsl:with-param name="param-value" select="."/>
    </xsl:call-template><xsl:if test="position() != last()">,</xsl:if>
    </xsl:for-each>
  )
</xsl:template>

<xsl:template match="/database/schema/table/field">
  <xsl:param name="param-is-upgrade"/>

  <xsl:text>[</xsl:text><xsl:value-of select="@name"/><xsl:text>]</xsl:text>

	<xsl:text> </xsl:text>
	<xsl:call-template name="data-type">
		<xsl:with-param name="param-type" select="@type"/>
		<xsl:with-param name="param-size" select="@size"/>
	</xsl:call-template>

	<xsl:text> </xsl:text>
	<xsl:call-template name="nullity">
		<xsl:with-param name="param-allow-null" select="@allow-null"/>
	</xsl:call-template>

	<xsl:text> </xsl:text>
	<xsl:call-template name="primary-key">
		<xsl:with-param name="param-primary-key" select="@primary-key"/>
	</xsl:call-template>

	<xsl:text> </xsl:text>
	<xsl:call-template name="default-value">
    <xsl:with-param name="param-is-upgrade" select="$param-is-upgrade"/>
		<xsl:with-param name="param-type" select="@type"/>
		<xsl:with-param name="param-value" select="@default"/>
	</xsl:call-template>

  <xsl:text> </xsl:text>
  <xsl:if test="@constraint">
    <xsl:variable name="tmp_constraint">
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="@constraint" />
        <xsl:with-param name="replace" select="'{SERVER_NAME}'" />
        <xsl:with-param name="by" select="$var-server-name" />
      </xsl:call-template>
    </xsl:variable>
    CONSTRAINT <xsl:value-of select="$tmp_constraint"/>
  </xsl:if>
</xsl:template>

<xsl:template name="data-type">
	<xsl:param name="param-type"/>
	<xsl:param name="param-size"/>
  <xsl:variable name="param-database-type" select="$var-database-type"/>
  <xsl:variable name="generic-data-type" select="document('dbSqlDataTypes.xml')/sql_datatypes/*[@name=$param-database-type]"/>
  <xsl:value-of select="$generic-data-type/*[name()=$param-type]"/>
  <xsl:if test="$param-type='text'">(<xsl:value-of select="$param-size"/>)<xsl:if test="$param-database-type='JET'"> WITH COMP</xsl:if></xsl:if>
  <xsl:if test="$param-type='varbinary' and $param-database-type='SQLSVR'">(<xsl:value-of select="$param-size"/>)</xsl:if>
  
  <xsl:text> </xsl:text>
  <!--xsl:choose>
		<xsl:when test="$param-type='identity'">IDENTITY</xsl:when>
		<xsl:when test="$param-type='longint'" >DECIMAL</xsl:when>
		<xsl:when test="$param-type='integer'" >INTEGER</xsl:when>
		<xsl:when test="$param-type='smallint'">SMALLINT</xsl:when>
		<xsl:when test="$param-type='tinyint'" >BYTE</xsl:when>
		<xsl:when test="$param-type='boolean'" >BIT</xsl:when>
		<xsl:when test="$param-type='longtext'">LONGTEXT WITH COMP</xsl:when>
		<xsl:when test="$param-type='text'"    >TEXT(<xsl:value-of select="$param-size"/>) WITH COMP</xsl:when>
		<xsl:when test="$param-type='datetime'">DATETIME</xsl:when>
		<xsl:when test="$param-type='double'"  >DOUBLE</xsl:when>
		<xsl:when test="$param-type='float'"   >FLOAT</xsl:when>
		<xsl:when test="$param-type='guid'"    >GUID</xsl:when>
	</xsl:choose-->
</xsl:template>

<xsl:template name="nullity">
	<xsl:param name="param-allow-null"/>
	<xsl:choose>
		<xsl:when test="$param-allow-null='true'" >NULL</xsl:when>
		<xsl:when test="$param-allow-null='false'">NOT NULL</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template name="primary-key">
	<xsl:param name="param-primary-key"/>
	<xsl:if test="$param-primary-key">PRIMARY KEY</xsl:if>
</xsl:template>

<xsl:template name="default-value">
  <xsl:param name="param-is-upgrade"/>
	<xsl:param name="param-type"/>
	<xsl:param name="param-value"/>
	<xsl:if test="$param-value">
		<xsl:text>DEFAULT </xsl:text>
    <xsl:call-template name="sql-value">
      <xsl:with-param name="param-type" select="$param-type"/>
      <xsl:with-param name="param-value" select="$param-value"/>
    </xsl:call-template>
	</xsl:if>
</xsl:template>

<!--// Template: Create View -->
<xsl:template match="/database/schema/view">
	CREATE VIEW [<xsl:value-of select="concat(@name,'_',$var-server-name)"/>]
	(
		<xsl:for-each select="column">
		[<xsl:value-of select="@name"/>]<xsl:if test="position()!=last()">,</xsl:if>
		</xsl:for-each>
	)
	AS SELECT<xsl:for-each select="column">
		<xsl:variable name="var-fieldname">
			<xsl:choose>
				<xsl:when test="not(@from-field)"><xsl:value-of select="@name"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="@from-field"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		[<xsl:value-of select="concat(@from-table,'_',$var-server-name)"/>].[<xsl:value-of select="$var-fieldname"/>]<xsl:if test="position()!=last()">,</xsl:if>
	</xsl:for-each>
	FROM <xsl:apply-templates select="from/*"/>
  <xsl:if test="from/@where">
    <xsl:variable name="tmp_where">
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="from/@where" />
        <xsl:with-param name="replace" select="'{SERVER_NAME}'" />
        <xsl:with-param name="by" select="$var-server-name" />
      </xsl:call-template>
    </xsl:variable>
    WHERE <xsl:value-of select="$tmp_where"/>
 </xsl:if>
	
</xsl:template>

<xsl:template match="inner-join|outter-join|left-join|right-join">
  <xsl:variable name="tmp_on">
    <xsl:call-template name="string-replace-all">
      <xsl:with-param name="text" select="@on" />
      <xsl:with-param name="replace" select="'{SERVER_NAME}'" />
      <xsl:with-param name="by" select="$var-server-name" />
    </xsl:call-template>
  </xsl:variable>
	([<xsl:value-of select="concat(table[1]/@name,'_',$var-server-name)"/>] <xsl:choose>
		<xsl:when test="name(current()) = 'inner-join'" >INNER JOIN</xsl:when>
		<xsl:when test="name(current()) = 'outter-join'">OUTTER JOIN</xsl:when>
		<xsl:when test="name(current()) = 'left-join'"  >LEFT JOIN</xsl:when>
		<xsl:when test="name(current()) = 'right-join'" >RIGHT JOIN</xsl:when>
	</xsl:choose> [<xsl:value-of select="concat(table[2]/@name,'_',$var-server-name)"/>]
		ON <xsl:value-of select="$tmp_on"/>)
</xsl:template>

<xsl:template match="from/table">
  [<xsl:value-of select="concat(@name,'_',$var-server-name)"/>]
</xsl:template>
  
<xsl:template name="create-index">
  <xsl:param name="param-table"/>
  <xsl:param name="param-field"/>
  <xsl:text>CREATE INDEX [idx</xsl:text><xsl:value-of select="$param-field/@name"/><xsl:text>] </xsl:text>
  <xsl:text>ON </xsl:text>
  <xsl:text> [</xsl:text><xsl:value-of select="concat($param-table/@name,'_',$var-server-name)"/><xsl:text>] </xsl:text>
  <xsl:text> (</xsl:text>
  <xsl:text> [</xsl:text><xsl:value-of select="$param-field/@name"/><xsl:text>] </xsl:text>
  <xsl:text> </xsl:text>
  <xsl:choose>
    <xsl:when test="$param-field/@index='asc'"><xsl:text>ASC</xsl:text></xsl:when>
    <xsl:when test="$param-field/@index='desc'"><xsl:text>DESC</xsl:text></xsl:when>
  </xsl:choose>
  <xsl:text>) </xsl:text>
</xsl:template>

<xsl:template name="sql-value">
  <xsl:param name="param-type"/>
  <xsl:param name="param-value"/>
  <xsl:if test="$param-value">
		<xsl:choose>
			<xsl:when test="$param-type='longtext' or $param-type='text'">
        <xsl:text>'</xsl:text>
          <xsl:call-template name="escape_quot">
          <xsl:with-param name="substr" select="$param-value"/>
        </xsl:call-template><xsl:text>'</xsl:text>
      </xsl:when>
      <xsl:when test="$param-type='boolean'">
        <xsl:choose>
          <xsl:when test="$param-value='0'">0</xsl:when>
          <xsl:otherwise>-1</xsl:otherwise>
        </xsl:choose>
      </xsl:when>
			<xsl:otherwise>
        <xsl:value-of select="$param-value"/>
      </xsl:otherwise>
		</xsl:choose>
	</xsl:if>
</xsl:template>

<xsl:template name="escape_quot">
  <xsl:param name="substr"/>
  <xsl:variable name="var-single-quote">&apos;</xsl:variable>
  <xsl:choose>
    <xsl:when test="contains($substr, $var-single-quote)">
      <xsl:variable name="str_before_quot" select="substring-before($substr, $var-single-quote)"/>
      <xsl:variable name="str_after_quot" select="substring-after($substr, $var-single-quote)"/>
      <xsl:value-of select="$str_before_quot"/>''<xsl:text/>
      <xsl:call-template name="escape_quot">
        <xsl:with-param name="substr" select="$str_after_quot"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="$substr"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

</xsl:stylesheet> 
